.. Copyright (c) 2017-2026 Juancarlo Añez (apalala@gmail.com)
.. SPDX-License-Identifier: BSD-4-Clause

.. include:: links_contributors.rst

.. |dragon| unicode:: 0x7ADC .. unicode dragon
.. |TatSu| replace:: |dragon| **TatSu**

.. _ANTLR: http://www.antlr.org/
.. _AST: http://en.wikipedia.org/wiki/Abstract_syntax_tree
.. _AST: http://en.wikipedia.org/wiki/Abstract_syntax_tree
.. _Abstract Syntax Tree: http://en.wikipedia.org/wiki/Abstract_syntax_tree
.. _Abstract Syntax Tree: http://en.wikipedia.org/wiki/Abstract_syntax_tree
.. _Algol W: http://en.wikipedia.org/wiki/Algol_W
.. _Algorithms + Data Structures = Programs: http://www.amazon.com/Algorithms-Structures-Prentice-Hall-Automatic-Computation/dp/0130224189/
.. _BSD: http://en.wikipedia.org/wiki/BSD_licenses#2-clause_license_.28.22Simplified_BSD_License.22_or_.22FreeBSD_License.22.29
.. _C: http://en.wikipedia.org/wiki/C_language
.. _COBOL: https://en.wikipedia.org/wiki/COBOL
.. _CSAIL at MIT: http://www.csail.mit.edu/
.. _CST: https://en.wikipedia.org/wiki/Parse_tree
.. _Cyclomatic complexity: http://en.wikipedia.org/wiki/Cyclomatic_complexity
.. _Dennis Ritchie: http://en.wikipedia.org/wiki/Dennis_Ritchie
.. _EBNF: https://en.wikipedia.org/wiki/Extended_Backus–Naur_form
.. _English: http://en.wikipedia.org/wiki/English_grammar
.. _Euler: http://en.wikipedia.org/wiki/Euler_programming_language
.. _Grako: https://pypi.python.org/pypi/grako/
.. _ISO EBNF: https://en.wikipedia.org/wiki/Extended_Backus–Naur_form
.. _Invoke: https://www.pyinvoke.org
.. _Jack: http://en.wikipedia.org/wiki/Javacc
.. _Japanese: http://en.wikipedia.org/wiki/Japanese_grammar
.. _Java: https://en.wikipedia.org/wiki/Java
.. _KLOC: http://en.wikipedia.org/wiki/KLOC
.. _Keywords: https://en.wikipedia.org/wiki/Reserved_word
.. _LICENSE: LICENSE
.. _LL(1): http://en.wikipedia.org/wiki/LL(1)
.. _MediaWiki: http://www.mediawiki.org/wiki/MediaWiki
.. _Modula-2: http://en.wikipedia.org/wiki/Modula-2
.. _Modula: http://en.wikipedia.org/wiki/Modula
.. _Oberon-2: http://en.wikipedia.org/wiki/Oberon-2
.. _Oberon: http://en.wikipedia.org/wiki/Oberon_(programming_language)
.. _PEG and Packrat parsing mailing list: https://lists.csail.mit.edu/mailman/listinfo/peg
.. _PEG.js: http://pegjs.majda.cz/
.. _PEG: http://en.wikipedia.org/wiki/Parsing_expression_grammar
.. _PL/0: http://en.wikipedia.org/wiki/PL/0
.. _PLY: http://www.dabeaz.com/ply/ply.html#ply_nn22
.. _Packrat: http://bford.info/packrat/
.. _Pascal: https://en.wikipedia.org/wiki/Pascal_(programming_language)
.. _Perl: http://www.perl.org/
.. _PyCharm: https://www.jetbrains.com/pycharm/
.. _PyPy team: http://pypy.org/people.html
.. _PyPy: http://pypy.org/
.. _Python Weekly: http://www.pythonweekly.com/
.. _Python: http://python.org
.. _Reserved Words: https://en.wikipedia.org/wiki/Reserved_word
.. _Ruby: http://www.ruby-lang.org/
.. _SQL: https://en.wikipedia.org/wiki/SQL
.. _Semantic Graph: http://en.wikipedia.org/wiki/Abstract_semantic_graph
.. _Sphinx: https://www.sphinx-doc.org/en/master/
.. _StackOverflow: http://stackoverflow.com/tags/tatsu/info
.. _Sublime Text: https://www.sublimetext.com
.. _TatSu Forum: https://groups.google.com/forum/?fromgroups#!forum/tatsu
.. _UCAB: http://www.ucab.edu.ve/
.. _USB: http://www.usb.ve/
.. _Unix: http://en.wikipedia.org/wiki/Unix
.. _VIM: http://www.vim.org/
.. _VSCode: https://code.visualstudio.com
.. _WTK: http://en.wikipedia.org/wiki/Well-known_text
.. _Warth et al: http://www.vpri.org/pdf/tr2007002_packrat.pdf
.. _Well-known text: http://en.wikipedia.org/wiki/Well-known_text
.. _Wirth: http://en.wikipedia.org/wiki/Niklaus_Wirth
.. _`left-recursive`: https://en.wikipedia.org/wiki/Left_recursion
.. _`make a donation`: https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=2TW56SV6WNJV6
.. _blog post: http://dietbuddha.blogspot.com/2012/12/52python-encapsulating-exceptions-with.html
.. _colorama: https://pypi.python.org/pypi/colorama/
.. _context managers: http://docs.python.org/2/library/contextlib.html
.. _declensions: http://en.wikipedia.org/wiki/Declension
.. _email: mailto:apalala@gmail.com
.. _exceptions: http://www.jeffknupp.com/blog/2013/02/06/write-cleaner-python-use-exceptions/
.. _graphviz: https://pypi.python.org/pypi/graphviz
.. _introduced: http://dl.acm.org/citation.cfm?id=964001.964011
.. _keyword: https://en.wikipedia.org/wiki/Reserved_word
.. _keywords: https://en.wikipedia.org/wiki/Reserved_word
.. _lambdafu: http://blog.marcus-brinkmann.de/
.. _make: https://www.gnu.org/software/make/manual/make.html
.. _memoizing: http://en.wikipedia.org/wiki/Memoization
.. _parsewkt: https://github.com/cleder/parsewkt
.. _raw string literal: https://docs.python.org/3/reference/lexical_analysis.html#string-and-bytes-literals
.. _re: https://docs.python.org/3.4/library/re.html
.. _regex: https://pypi.python.org/pypi/regex
.. _regular languages: https://en.wikipedia.org/wiki/Regular_language
.. _smc.mw: https://github.com/lambdafu/smc.mw
.. _uv: https://docs.astral.sh/uv/
